<?php

namespace App\Dto\Output;

use ApiPlatform\Metadata\Get;
use App\Entity\GitImageRepository;
use App\Entity\ImageImageRepository;
use Symfony\Component\Serializer\Annotation\Groups;

#[Get(shortName: 'GitImageRepository')]
final class GitImageRepositoryOutput extends AbstractOutput
{
    #[Groups(['git-image-repository:read', 'image:read'])]
    public ?ImageOutput $image = null;

    #[Groups(['git-image-repository:read', 'image:read'])]
    public ?ImageRepositoryOutput $imageRepository = null;

    #[Groups(['git-image-repository:read', 'image:read'])]
    public string $status = '';

    #[Groups(['git-image-repository:read', 'image:read'])]
    public ?string $description = '';

    #[Groups(['git-image-repository:read', 'image:read'])]
    public string $name = '';

    #[Groups(['git-image-repository:read', 'image:read'])]
    public ?string $branch = '';

    #[Groups(['git-image-repository:read', 'image:read'])]
    public ?string $tag = '';

    #[Groups(['git-image-repository:read', 'image:read'])]
    public \DateTime $createdAt;

    #[Groups(['git-image-repository:read', 'image:read'])]
    public ?string $createdBy = null;

    public function __construct(GitImageRepository $gitImageRepository, array $context = [])
    {
        parent::__construct($gitImageRepository);

        if (isset($context['groups']) && in_array('git-image-repository:read', $context['groups'])) {
            if ($gitImageRepository->getImage()) {
                $this->image = new ImageOutput($gitImageRepository->getImage());
            }
        }

        if ($gitImageRepository->getRepository()) {
            $this->imageRepository = new ImageRepositoryOutput($gitImageRepository->getRepository());
        }

        $this->name = $gitImageRepository->getName();
        $this->description = $gitImageRepository->getDescription();
        $this->status = $gitImageRepository->getStatus();
        $this->branch = $gitImageRepository->getBranch();
        $this->tag = $gitImageRepository->getTag();
        $this->createdAt = $gitImageRepository->getCreatedAt();
        $this->createdBy = $gitImageRepository->getCreatedBy();
    }
}